# 025

|                                                                      | 025-1wj100722v0w   | 025-1wj105050v0w   | 025-1wj080831v0w    | 025-1wj100725v0t   |
|:---------------------------------------------------------------------|:-------------------|:-------------------|:--------------------|:-------------------|
| bindTime                                                             | 1721298985507      | 1748701351443      | 1740685929815       | 1694675286314      |
| createTime                                                           | 0                  | 0                  | 0                   | 0                  |
| deviceFeatureCode                                                    | 1wj100722v0w       | 1wj105050v0w       | 1wj080831v0w        | 1wj100725v0t       |
| deviceFeatureName                                                    | WFSE1015-LVW001    | WDSE1214-EVAJMW    | WF3S8014-PVW004-001 | WFSE1015-LVT001    |
| deviceId                                                             | <redacted>         | <redacted>         | <redacted>          | <redacted>         |
| deviceNickName                                                       | Washing Machine    | Washing Machine    | Wasching Machine    | Washing machine    |
| deviceTypeCode                                                       | 025                | 025                | 025                 | 025                |
| deviceTypeName                                                       |                    |                    |                     |                    |
| isShow                                                               | 1                  | 1                  | 1                   |                    |
| offlineState                                                         | 0                  | 1                  | 0                   | 1                  |
| puid                                                                 | <redacted>         | <redacted>         | <redacted>          | <redacted>         |
| role                                                                 | 1                  | 1                  | 1                   | 1                  |
| roomId                                                               | 5146619            | 8530188            | 7498796             | 2708438            |
| roomName                                                             | Laundry Room       | Laundry Room       | Waschküche          | Laundry            |
| seq                                                                  | 0                  | 0                  | 0                   | 0                  |
| statusList. slotdry                                                  | 0                  | 0                  | 0                   |                    |
| statusList. slotdry_flag                                             |                    | 0                  |                     |                    |
| statusList. slotdry_flag1                                            |                    | 0                  |                     |                    |
| statusList.Actions                                                   | 0                  | 0                  | 0                   | 0                  |
| statusList.Add_water_flag                                            |                    | 0                  |                     |                    |
| statusList.AirDryFlag                                                | 0                  | 0                  | 0                   | 0                  |
| statusList.AirWashTime                                               | 0                  | 0                  | 0                   | 0                  |
| statusList.AntiCrease                                                | 0                  | 0                  | 0                   | 0                  |
| statusList.AntiCrease_flag                                           | 0                  | 0                  | 0                   |                    |
| statusList.ApplicationPermissions                                    | 2                  | 2                  | 1                   | 2                  |
| statusList.AquaPreserve                                              | 0                  | 0                  | 0                   | 0                  |
| statusList.AquaPreserve_Flag                                         | 0                  | 0                  | 0                   | 0                  |
| statusList.AutoDose                                                  | 0                  | 0                  | 0                   | 0                  |
| statusList.AutoDoseType                                              | 0                  | 0                  | 0                   |                    |
| statusList.AutoDose_flag                                             | 0                  | 0                  | 0                   |                    |
| statusList.AutoTubClean                                              | 0                  | 0                  | 0                   | 0                  |
| statusList.BathingWaterPumpState                                     | 0                  | 0                  | 0                   | 0                  |
| statusList.BathingWaterPump_Rinse                                    | 0                  | 0                  | 0                   | 0                  |
| statusList.BathingWaterPump_Wash                                     | 0                  | 0                  | 0                   | 0                  |
| statusList.Cancle_DelayEnd                                           | 0                  | 0                  | 0                   | 0                  |
| statusList.Child_lock                                                | 0                  | 0                  | 0                   | 0                  |
| statusList.Childlock_flag                                            | 0                  | 0                  | 0                   |                    |
| statusList.Childlock_newfuntion                                      | 0                  | 0                  | 0                   |                    |
| statusList.Childlock_pause                                           | 0                  | 0                  | 0                   |                    |
| statusList.ColdWash                                                  | 0                  | 0                  | 0                   |                    |
| statusList.Compartment_Inuse                                         | 0                  | 0                  | 0                   |                    |
| statusList.Compartment_switch                                        | 0                  | 0                  | 0                   |                    |
| statusList.CurProgDetergentDosage                                    | 0                  | 0                  | 0                   |                    |
| statusList.CurProgDetergentDosageNo_Auto                             | 0                  | 0                  | 0                   |                    |
| statusList.CurProgSoftnerDosage                                      | 0                  | 0                  | 0                   |                    |
| statusList.CurProgSoftnerDosageNo_Auto                               | 0                  | 0                  | 0                   |                    |
| statusList.CurrentProgram_High_WaterLevel_InflowTime                 | 0                  | 0                  | 0                   | 0                  |
| statusList.CurrentProgram_High_WaterLevel_Starting_WaterLevelValue   | 0                  | 0                  | 0                   | 0                  |
| statusList.CurrentProgram_Low_WaterLevel_InflowTime                  | 0                  | 0                  | 0                   | 0                  |
| statusList.CurrentProgram_Medium_WaterLevel_InflowTime               | 0                  | 0                  | 0                   | 0                  |
| statusList.CurrentProgram_Medium_WaterLevel_Starting_WaterLevelValue | 0                  | 0                  | 0                   | 0                  |
| statusList.Current_program_phase                                     | 0                  | 4                  | 3                   | 0                  |
| statusList.D1_program_ID                                             | 0                  | 0                  | 0                   |                    |
| statusList.D2_program_ID                                             | 0                  | 0                  | 0                   |                    |
| statusList.D3_program_ID                                             | 0                  | 0                  | 0                   |                    |
| statusList.Dat3                                                      | 0                  | 0                  | 0                   |                    |
| statusList.Data1                                                     | 0                  | 0                  | 0                   |                    |
| statusList.Data2                                                     | 0                  | 0                  | 0                   |                    |
| statusList.Data4                                                     | 0                  | 0                  | 0                   |                    |
| statusList.Data5                                                     | 0                  | 0                  | 0                   |                    |
| statusList.DefaultSpinSpeed                                          | 14                 | 14                 | 12                  | 14                 |
| statusList.Degerming_State                                           |                    |                    |                     | 0                  |
| statusList.DelayEndTime                                              | 0                  | 0                  | 0                   | 0                  |
| statusList.DelayEndTime_Minute                                       | 0                  | 0                  | 0                   | 0                  |
| statusList.Detergent                                                 | 0                  | 1                  | 0                   | 1                  |
| statusList.DetergentStandardDosage                                   | 0                  | 0                  | 0                   | 0                  |
| statusList.DetergentStandardDosage_flag                              | 0                  | 0                  | 0                   |                    |
| statusList.Detergent_display                                         | 1                  | 1                  | 1                   | 1                  |
| statusList.Detergent_flag                                            | 0                  | 0                  | 0                   |                    |
| statusList.Detergent_state                                           | 0                  | 0                  | 0                   | 0                  |
| statusList.Door_status                                               | 1                  | 3                  | 1                   | 1                  |
| statusList.Dose_Detergent_amount                                     | 0                  | 1                  | 0                   | 1                  |
| statusList.Dose_Softener_amount                                      | 0                  | 1                  | 0                   | 1                  |
| statusList.DownLight                                                 | 0                  | 0                  | 0                   | 0                  |
| statusList.DownLight_LightTime                                       | 0                  | 0                  | 0                   | 0                  |
| statusList.Downloadprogram                                           | 0                  | 0                  | 0                   |                    |
| statusList.DrumCleanCycle_RunsNumber                                 | 0                  | 0                  | 0                   | 0                  |
| statusList.DrumCleanFlag                                             | 0                  | 0                  | 0                   | 0                  |
| statusList.DrumCleanSwitch                                           | 0                  | 0                  | 0                   |                    |
| statusList.DrumCleanWashCount                                        | 0                  | 0                  | 0                   | 0                  |
| statusList.DryLeve_flag                                              | 0                  | 0                  | 0                   |                    |
| statusList.DryMode_flag                                              | 0                  | 0                  | 0                   |                    |
| statusList.DryModel                                                  | 0                  | 0                  | 0                   |                    |
| statusList.DryOpen_DefaultSpinSpeed                                  | 14                 | 14                 | 0                   | 14                 |
| statusList.DryingSwitch                                              | 0                  | 0                  | 0                   | 0                  |
| statusList.EcoMode                                                   | 0                  | 0                  | 0                   | 0                  |
| statusList.Electricit_consumption_decimal                            | 0                  | 0                  | 0                   | 19                 |
| statusList.Electricit_consumption_int                                | 0                  | 0                  | 0                   | 0                  |
| statusList.Energy_estimate                                           | 50                 | 30                 | 50                  | 40                 |
| statusList.EnterPerformanceMode_dry1_ConditionType                   | 0                  | 0                  | 0                   | 0                  |
| statusList.EnterPerformanceMode_dry1_MainWashTime                    | 0                  | 0                  | 0                   | 0                  |
| statusList.EnterPerformanceMode_wash1_ConditionType                  | 0                  | 0                  | 0                   | 0                  |
| statusList.EnterPerformanceMode_wash1_MainWashTime                   | 0                  | 0                  | 0                   | 0                  |
| statusList.EnterPerformanceMode_wash2_ConditionType                  | 0                  | 0                  | 0                   | 0                  |
| statusList.EnterPerformanceMode_wash2_MainWashTime                   | 0                  | 0                  | 0                   | 0                  |
| statusList.ExtraRinseNum                                             | 0                  | 0                  | 0                   | 0                  |
| statusList.ExtraRinseNum_Flag                                        | 0                  | 0                  | 0                   | 0                  |
| statusList.Extra_Rinse                                               | 0                  | 0                  | 0                   | 0                  |
| statusList.Favour_program_ID                                         | 0                  | 0                  | 0                   |                    |
| statusList.Filterclean_dry                                           | 0                  | 0                  | 0                   |                    |
| statusList.Filterclean_dryCount                                      | 0                  | 0                  | 0                   |                    |
| statusList.Filterclean_dryFlag                                       | 0                  | 0                  | 0                   |                    |
| statusList.Filterclean_wash                                          | 0                  | 0                  | 0                   |                    |
| statusList.Filterclean_washCount                                     | 0                  | 0                  | 0                   |                    |
| statusList.Filterclean_washFlag                                      | 0                  | 0                  | 0                   |                    |
| statusList.FlexibleSpinTime_Flag                                     | 1                  | 1                  | 1                   | 1                  |
| statusList.Fluffysoft                                                | 0                  | 0                  | 0                   |                    |
| statusList.Fluffysoft_flag                                           |                    | 0                  |                     |                    |
| statusList.Fluffysoft_flag1                                          |                    | 0                  |                     |                    |
| statusList.Half_Load                                                 | 0                  | 0                  | 0                   | 0                  |
| statusList.Hard_pairing_commond                                      | 0                  | 0                  | 0                   | 0                  |
| statusList.Hard_pairing_status                                       | 0                  | 0                  | 0                   | 0                  |
| statusList.ID1                                                       | 0                  | 0                  | 0                   |                    |
| statusList.ID2                                                       | 0                  | 0                  | 0                   |                    |
| statusList.ID3                                                       | 0                  | 0                  | 0                   |                    |
| statusList.ID4                                                       | 0                  | 0                  | 0                   |                    |
| statusList.ID5                                                       | 0                  | 0                  | 0                   |                    |
| statusList.InitializationprogramID                                   |                    | 0                  |                     |                    |
| statusList.IntensiveWash                                             | 0                  | 0                  | 0                   | 0                  |
| statusList.Intensive_flag                                            | 0                  | 0                  | 0                   |                    |
| statusList.Language                                                  | 0                  | 0                  | 0                   | 0                  |
| statusList.Last_completed_running_process                            | 0                  | 0                  | 0                   | 0                  |
| statusList.LidOpenFlag                                               | 0                  | 0                  | 0                   | 0                  |
| statusList.MainWashTimeList                                          | 0                  | 0                  | 0                   | 0                  |
| statusList.MainWashTimeUseIndex                                      | 4                  | 2                  | 4                   | 2                  |
| statusList.No_AutoDoseSwitch                                         | 0                  | 0                  | 0                   |                    |
| statusList.OTA_Num1                                                  | 0                  | 0                  | 0                   |                    |
| statusList.OTA_Sucess                                                | 0                  | 0                  | 0                   |                    |
| statusList.OnceWaterInRinse_Time                                     | 0                  | 0                  | 0                   | 0                  |
| statusList.PerformanceMode_Flag                                      | 0                  | 0                  | 0                   |                    |
| statusList.PerformanceMode_MainWashTime                              | 0                  | 0                  | 0                   |                    |
| statusList.PowerSaveDeleteTime                                       | 0                  | 0                  | 0                   | 0                  |
| statusList.Power_Save                                                | 0                  | 0                  | 0                   | 0                  |
| statusList.PreSoak                                                   | 0                  | 0                  | 0                   | 0                  |
| statusList.PreSoakFlag                                               | 0                  | 0                  | 0                   | 0                  |
| statusList.Prewash                                                   | 0                  | 0                  | 0                   | 0                  |
| statusList.Program_end_to_shutdown_time_in_minutes                   | 0                  | 0                  | 0                   | 0                  |
| statusList.PumCleanRemaintime                                        | 0                  | 0                  | 0                   |                    |
| statusList.PumCleanTotaltime                                         | 0                  | 0                  | 0                   |                    |
| statusList.PumCleanflag                                              | 0                  | 0                  | 0                   |                    |
| statusList.QuickerMode                                               | 0                  | 0                  | 0                   |                    |
| statusList.Quiet_model                                               | 0                  | 0                  | 0                   | 0                  |
| statusList.RinseNum                                                  | 3                  | 3                  | 2                   | 3                  |
| statusList.RinseNum_ContainExtraRinse                                | 0                  | 0                  | 0                   | 0                  |
| statusList.RinseNum_Index                                            | 0                  | 0                  | 0                   | 0                  |
| statusList.ScreenSaverTime                                           | 0                  | 0                  | 0                   | 0                  |
| statusList.Selected _programID_OTA                                   | 0                  | 0                  | 0                   |                    |
| statusList.Selected_program_ID                                       | 7                  | 7                  | 42                  | 7                  |
| statusList.Selected_program_Water_Add                                | 0                  | 0                  | 0                   | 0                  |
| statusList.Selected_program_remaining_time_in_minutes                | 209                | 46                 | 58                  | 1                  |
| statusList.Selected_program_total_running_time_in_minutes            | 209                | 129                | 58                  | 1                  |
| statusList.Selected_program_total_time_in_minutes                    | 209                | 129                | 58                  | 1                  |
| statusList.Session_pairing_commond                                   | 0                  | 0                  | 0                   | 0                  |
| statusList.Session_pairing_states                                    | 0                  | 0                  | 0                   | 0                  |
| statusList.SingleAirDry                                              | 0                  | 0                  | 0                   | 0                  |
| statusList.SkipDelayProcess                                          | 0                  | 0                  | 0                   | 0                  |
| statusList.Softener                                                  | 0                  | 1                  | 0                   | 1                  |
| statusList.Softener Compartment                                      | 0                  | 0                  | 0                   |                    |
| statusList.SoftenerCompartment_flag                                  | 0                  | 0                  | 0                   |                    |
| statusList.Softener_state                                            | 0                  | 0                  | 0                   | 1                  |
| statusList.Softer_display                                            | 1                  | 1                  | 1                   | 1                  |
| statusList.Softer_flag                                               | 0                  | 0                  | 0                   |                    |
| statusList.SoftnerStandardDosage                                     | 0                  | 0                  | 0                   | 0                  |
| statusList.SoftnerStandardDosage_flag                                | 0                  | 0                  | 0                   |                    |
| statusList.SoilLeverFlag                                             | 0                  | 0                  | 0                   | 0                  |
| statusList.Soil_Lever                                                | 2                  | 2                  | 0                   | 2                  |
| statusList.Sound_setting                                             | 3                  | 3                  | 3                   | 3                  |
| statusList.SpinSpeedUseIndex                                         | 0                  | 0                  | 0                   | 0                  |
| statusList.Spin_speed_rpm                                            | 14                 | 14                 | 12                  | 10                 |
| statusList.Spintime_Index                                            | 0                  | 0                  | 0                   | 0                  |
| statusList.Stain_removal                                             | 0                  | 0                  | 0                   | 0                  |
| statusList.StandardElectricitConsumption_int                         | 0                  | 0                  | 0                   | 0                  |
| statusList.StandardElectricitconsumption_decimal                     | 0                  | 0                  | 0                   | 0                  |
| statusList.StandardWaterConsumption_decimal                          | 0                  | 0                  | 0                   | 0                  |
| statusList.StandardWaterConsumption_int                              | 0                  | 0                  | 0                   | 0                  |
| statusList.Steam                                                     | 0                  | 1                  | 0                   | 0                  |
| statusList.Temp_Index                                                | 0                  | 0                  | 0                   | 0                  |
| statusList.Temp_wave                                                 | 0                  | 0                  | 0                   | 0                  |
| statusList.Temp_wave_flag                                            | 0                  | 0                  | 0                   | 0                  |
| statusList.Temperature_0_DefaultMainWashTime                         | 0                  | 0                  | 0                   | 0                  |
| statusList.Temperature_2_DefaultMainWashTime                         | 0                  | 0                  | 0                   | 0                  |
| statusList.Temperature_3_DefaultMainWashTime                         | 0                  | 0                  | 0                   | 0                  |
| statusList.Temperature_4_DefaultMainWashTime                         | 0                  | 0                  | 0                   | 0                  |
| statusList.Temperature_6_DefaultMainWashTime                         | 0                  | 0                  | 0                   | 0                  |
| statusList.Temperature_9_DefaultMainWashTime                         | 0                  | 0                  | 0                   | 0                  |
| statusList.Temperature_Default_DefaultMainWashTime                   | 140                | 140                | 25                  | 140                |
| statusList.Testdata_data                                             | 0                  | 0                  | 0                   | 0                  |
| statusList.Testdata_month                                            | 0                  | 0                  | 0                   | 0                  |
| statusList.Testdata_year                                             | 0                  | 0                  | 0                   | 0                  |
| statusList.Time_Save                                                 | 0                  | 0                  | 0                   | 0                  |
| statusList.UV_Light                                                  | 0                  | 0                  | 0                   | 0                  |
| statusList.WarmWaterWashing                                          | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingTimeIndex                                          | 0                  | 0                  | 0                   |                    |
| statusList.WashingTimeIndex                                          |                    |                    |                     | 0                  |
| statusList.WashingWizzard_Cloth                                      | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_Cloth_colour                               | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_Cloth_colour_fifth                         | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_Cloth_colour_fourth                        | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_Cloth_colour_second                        | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_Cloth_colour_third                         | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_Cloth_dirty                                | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_Cloth_dirty_first                          | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_Cloth_dirty_second                         | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_Cloth_dirty_third                          | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_Cloth_olour_first                          | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_Cloth_sensitive                            | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_Cloth_sensitive_first                      | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_Cloth_sensitive_second                     | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_Cloth_sensitive_third                      | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_Cloth_stains_eighth                        | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_Cloth_stains_fifth                         | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_Cloth_stains_first                         | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_Cloth_stains_fourth                        | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_Cloth_stains_ninth                         | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_Cloth_stains_second                        | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_Cloth_stains_seventh                       | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_Cloth_stains_sixth                         | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_Cloth_stains_third                         | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_ClothingType                               | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_ClothingType_eighth                        | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_ClothingType_eleventh                      | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_ClothingType_fifth                         | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_ClothingType_first                         | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_ClothingType_fourth                        | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_ClothingType_ninth                         | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_ClothingType_second                        | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_ClothingType_seventh                       | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_ClothingType_sixth                         | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_ClothingType_tenth                         | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_ClothingType_third                         | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_ClothingType_thirteenth                    | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_ClothingType_twelfth                       | 0                  | 0                  | 0                   | 0                  |
| statusList.WashingWizzard_flag                                       | 0                  | 0                  | 0                   | 0                  |
| statusList.Washing_drying_linkage_flag                               | 0                  | 0                  | 0                   | 0                  |
| statusList.Washing_drying_linkage_state                              | 0                  | 0                  | 0                   | 0                  |
| statusList.WaterLevel                                                | 0                  | 0                  | 0                   | 0                  |
| statusList.WaterLevelFlag                                            | 0                  | 0                  | 0                   | 0                  |
| statusList.WaterLevelIndex                                           | 0                  | 0                  | 0                   | 0                  |
| statusList.Water_consumption_decimal                                 | 0                  | 0                  | 0                   | 6                  |
| statusList.Water_consumption_int                                     | 0                  | 0                  | 0                   | 67                 |
| statusList.Water_hardness_setting                                    | 0                  | 0                  | 0                   | 0                  |
| statusList.WindDrying                                                | 0                  | 0                  | 0                   | 0                  |
| statusList.WindDryingFlag                                            | 0                  | 0                  | 0                   | 0                  |
| statusList.Zibian_program_ID                                         | 0                  | 0                  | -83886080           |                    |
| statusList.add_clothes_check                                         | 0                  | 0                  | 0                   | 0                  |
| statusList.daily_energy_kwh                                          | 0                  | 0                  | 0                   | 0                  |
| statusList.delay_actions_flag                                        | 0                  | 0                  | 0                   | 0                  |
| statusList.delayclose_flag                                           | 0                  | 0                  | 0                   |                    |
| statusList.dry_lever                                                 | 0                  | 0                  | 0                   | 0                  |
| statusList.dry_time                                                  | 0                  | 0                  | 0                   | 0                  |
| statusList.error_code                                                | 0                  | 0                  | 0                   | 0                  |
| statusList.hottime                                                   | 0                  | 0                  | 0                   |                    |
| statusList.machine_status                                            | 0                  | 2                  | 0                   | 0                  |
| statusList.mainwashtime                                              | 0                  | 60                 | 25                  |                    |
| statusList.mainwashtime_flag                                         | 0                  | 0                  | 0                   |                    |
| statusList.mian_wash_time                                            | 140                | 60                 | 25                  | 34                 |
| statusList.mute                                                      | 0                  | 0                  | 0                   | 0                  |
| statusList.once strong step time                                     | 0                  | 0                  | 0                   | 0                  |
| statusList.once_rinse_step_time                                      | 19                 | 19                 | 3                   | 14                 |
| statusList.onlyrinse_model                                           |                    | 0                  |                     |                    |
| statusList.onlyspin_model                                            |                    | 0                  |                     |                    |
| statusList.onlywash_model                                            |                    | 0                  |                     |                    |
| statusList.order_time_minimum_hour                                   | 4                  | 3                  | 1                   | 1                  |
| statusList.parse_lib_ota                                             | 0                  | 0                  | 0                   |                    |
| statusList.parse_lib_ver                                             | 20241213           | 20250520           | 20250124            | 20240412           |
| statusList.rinse_flag                                                | 0                  | 0                  | 0                   |                    |
| statusList.softener_tank                                             | 0                  | 0                  | 0                   |                    |
| statusList.speed_flag                                                | 0                  | 0                  | 0                   |                    |
| statusList.spin_time                                                 | 0                  | 12                 | 9                   | 0                  |
| statusList.spintime_flag                                             |                    | 0                  |                     |                    |
| statusList.stoprunning_flag                                          | 0                  | 0                  | 0                   | 0                  |
| statusList.tankclean                                                 | 0                  | 0                  | 0                   |                    |
| statusList.tankclean_flag                                            |                    | 0                  |                     |                    |
| statusList.tankclean_flag1                                           |                    | 0                  |                     |                    |
| statusList.temp_runing_flag                                          | 0                  | 0                  | 0                   | 0                  |
| statusList.temperature                                               | 4                  | 2                  | 4                   | 3                  |
| statusList.time_autoflag                                             | 0                  | 0                  | 0                   | 0                  |
| statusList.timezone                                                  | 0                  | 0                  | 0                   | 0                  |
| statusList.washFunction1                                             | 0                  | 0                  | 0                   | 0                  |
| statusList.wash_step_time_drain_water_spin_and_stop                  | 8                  | 8                  | 3                   | 8                  |
| statusList.washing_machine_type                                      | 0                  | 0                  | 0                   | 0                  |
| statusList.washing_machine_type_kg                                   | 24                 | 24                 | 20                  | 24                 |
| statusList.washing_machine_type_max_speed                            | 14                 | 14                 | 1                   | 14                 |
| statusList.washing_program_kg                                        | 0                  | 0                  | 0                   |                    |
| statusList.washingtime                                               | 0                  | 0                  | 0                   | 0                  |
| statusList.waterlevel_runing_flag                                    | 0                  | 0                  | 0                   | 0                  |
| useTime                                                              | 1721298985486      | 1748701351422      | 1740685929794       | 1694675286293      |
| wifiId                                                               | <redacted>         | <redacted>         | <redacted>          | <redacted>         |

## Generated from

- [`025`](025-1wj100722v0w.json)
- [`025`](025-1wj105050v0w.json)
- [`025`](025-1wj080831v0w.json)
- [`025`](025-1wj100725v0t.json)
